@@ -19,7 +19,7 @@ from rich_toolkit import RichToolkit
 from rich_toolkit.menu import Option
 
 from fastapi_cloud_cli.commands.login import login
-from fastapi_cloud_cli.utils.api import APIClient, BuildLogError, TooManyRetriesError
+from fastapi_cloud_cli.utils.api import APIClient, StreamLogError, TooManyRetriesError
 from fastapi_cloud_cli.utils.apps import AppConfig, get_app_config, write_app_config
 from fastapi_cloud_cli.utils.auth import Identity
 from fastapi_cloud_cli.utils.cli import get_rich_toolkit, handle_http_errors
@@ -429,7 +429,7 @@ def _wait_for_deployment(
 
                     last_message_changed_at = time.monotonic()
 
-        except (BuildLogError, TooManyRetriesError, TimeoutError) as e:
+        except (StreamLogError, TooManyRetriesError, TimeoutError) as e:
             progress.set_error(
                 dedent(f"""
                 [error]Build log streaming failed: {e}[/]
@@ -438,7 +438,7 @@ def _wait_for_deployment(
                 """).strip()
             )
 
-            raise typer.Exit(1) from e
+            raise typer.Exit(1) from None
 
 
 class SignupToWaitingList(BaseModel):
