@@ -47,7 +47,10 @@ def test_shows_a_message_if_app_is_not_configured(logged_in_cli: None) -> None:
 def test_shows_a_message_if_something_is_wrong(
     logged_in_cli: None, respx_mock: respx.MockRouter, configured_app: Path
 ) -> None:
-    respx_mock.post("/apps/123/environment-variables/").mock(return_value=Response(500))
+    respx_mock.post(
+        "/apps/123/environment-variables/",
+        json={"name": "SOME_VAR", "value": "secret", "is_secret": False},
+    ).mock(return_value=Response(500))
 
     with changing_dir(configured_app):
         result = runner.invoke(app, ["env", "set", "SOME_VAR", "secret"])
@@ -63,7 +66,10 @@ def test_shows_a_message_if_something_is_wrong(
 def test_shows_message_when_it_sets(
     logged_in_cli: None, respx_mock: respx.MockRouter, configured_app: Path
 ) -> None:
-    respx_mock.post("/apps/123/environment-variables/").mock(return_value=Response(200))
+    respx_mock.post(
+        "/apps/123/environment-variables/",
+        json={"name": "SOME_VAR", "value": "secret", "is_secret": False},
+    ).mock(return_value=Response(200))
 
     with changing_dir(configured_app):
         result = runner.invoke(app, ["env", "set", "SOME_VAR", "secret"])
@@ -78,7 +84,10 @@ def test_asks_for_name_and_value(
 ) -> None:
     steps = [*"SOME_VAR", Keys.ENTER, *"secret", Keys.ENTER]
 
-    respx_mock.post("/apps/123/environment-variables/").mock(return_value=Response(200))
+    respx_mock.post(
+        "/apps/123/environment-variables/",
+        json={"name": "SOME_VAR", "value": "secret", "is_secret": False},
+    ).mock(return_value=Response(200))
 
     with (
         changing_dir(configured_app),
@@ -93,4 +102,45 @@ def test_asks_for_name_and_value(
 
     assert "Environment variable SOME_VAR set" in result.output
 
+
+@pytest.mark.respx(base_url=settings.base_api_url)
+def test_asks_for_name_and_value_for_secret(
+    logged_in_cli: None, respx_mock: respx.MockRouter, configured_app: Path
+) -> None:
+    steps = [*"SOME_VAR", Keys.ENTER, *"secret", Keys.ENTER]
+
+    respx_mock.post(
+        "/apps/123/environment-variables/",
+        json={"name": "SOME_VAR", "value": "secret", "is_secret": True},
+    ).mock(return_value=Response(200))
+
+    with (
+        changing_dir(configured_app),
+        patch("rich_toolkit.container.getchar", side_effect=steps),
+    ):
+        result = runner.invoke(app, ["env", "set", "--secret"])
+
+    assert result.exit_code == 0
+
+    assert "Enter the name of the secret" in result.output
+    assert "Enter the secret value" in result.output
+
+    assert "Secret environment variable SOME_VAR set" in result.output
+
     assert "*" * 6 in result.output
+
+
+@pytest.mark.respx(base_url=settings.base_api_url)
+def test_sets_secret_flag(
+    logged_in_cli: None, respx_mock: respx.MockRouter, configured_app: Path
+) -> None:
+    respx_mock.post(
+        "/apps/123/environment-variables/",
+        json={"name": "SOME_VAR", "value": "secret", "is_secret": True},
+    ).mock(return_value=Response(200))
+
+    with changing_dir(configured_app):
+        result = runner.invoke(app, ["env", "set", "SOME_VAR", "secret", "--secret"])
+
+    assert result.exit_code == 0
+    assert "Secret environment variable SOME_VAR set" in result.output
